//
//  Scanbot Barcode Scanner SDK Flutter Plugin
//
//  Copyright (c) 2020 doo GmbH. All rights reserved.
//  https://scanbot.io/sdk
//

import Foundation
import ScanbotBarcodeScannerSDK

struct SDKInitializationConfig {
    
    let isLoggingEnabled: Bool
    let licenseCode: String
    let storageBaseDirectory: URL?
    let defaultEncrypter: SBSDKAESEncrypter?
    
    init?(from dictionary: [String: Any]) {
        guard let licenseCode = dictionary["licenseKey"] as? String else {
            return nil
        }
        self.licenseCode = licenseCode
        self.isLoggingEnabled = (dictionary["loggingEnabled"] as? Bool) ?? false
        
        if let url = dictionary["storageBaseDirectory"] as? String {
            self.storageBaseDirectory = URL(fileURLWithPath: url, isDirectory: true)
        } else {
            self.storageBaseDirectory = nil
        }
        
        if let encryptionParameters = dictionary["encryptionParameters"] as? [String: Any] {
            self.defaultEncrypter = SBSDKAESEncrypter(from: encryptionParameters)
        } else {
            self.defaultEncrypter = nil
        }
    }
}
