import 'dart:convert';
import 'dart:typed_data';
import 'dart:ui';

import 'package:barcode_scanner/barcode_scanning_data.dart';

void addColor(Color? color, String name, Map arguments) {
  if (color != null) arguments[name] = toColorString(color);
}

void addParam(dynamic argument, String name, Map arguments) {
  if (argument != null) arguments[name] = argument;
}

String? toColorString(Color? color) {
  return color != null ? '#${color.value.toRadixString(16)}' : null;
}

Color colorFromString(String color) {
  var valueString = color.replaceAll('#', '');
  var value = int.parse(valueString, radix: 16);
  return Color(value);
}

Uri stringToFileUri(String string) {
  return Uri.parse(string);
}

String fileUriToString(Uri uri) {
  return uri.toString();
}

Uint8List? uintListFromString(String? string) {
  if (string == null) {
    return null;
  }
  return const Base64Decoder().convert(string);
}

DateTime? dateFromString(String? string) {
  if (string == null) return null;
  return DateTime.parse(string);
}

const allDocumentFormatTypes = [
  AcceptedDocumentFormats.AAMVA,
  AcceptedDocumentFormats.BOARDING_PASS,
  AcceptedDocumentFormats.DE_MEDICAL_PLAN,
  AcceptedDocumentFormats.MEDICAL_CERTIFICATE,
  AcceptedDocumentFormats.ID_CARD_PDF_417,
  AcceptedDocumentFormats.SEPA,
  AcceptedDocumentFormats.SWISS_QR,
  AcceptedDocumentFormats.VCARD
];

const allBarcodeTypes = [
  BarcodeFormat.AZTEC,
  BarcodeFormat.CODABAR,
  BarcodeFormat.CODE_39,
  BarcodeFormat.CODE_93,
  BarcodeFormat.CODE_128,
  BarcodeFormat.DATA_MATRIX,
  BarcodeFormat.EAN_8,
  BarcodeFormat.EAN_13,
  BarcodeFormat.ITF,
  BarcodeFormat.PDF_417,
  BarcodeFormat.QR_CODE,
  BarcodeFormat.RSS_14,
  BarcodeFormat.RSS_EXPANDED,
  BarcodeFormat.UPC_A,
  BarcodeFormat.UPC_E,
  BarcodeFormat.MSI_PLESSEY
];
